@@ -395,6 +395,7 @@ fn test_builtin_functions() {
         Ok(Value::String(String::from("(1, 2, 3)")))
     );
     assert_eq!(eval("str::from()"), Ok(Value::String(String::from("()"))));
+    // Bitwise
     assert_eq!(eval("bitand(5, -1)"), Ok(Value::Int(5)));
     assert_eq!(eval("bitand(6, 5)"), Ok(Value::Int(4)));
     assert_eq!(eval("bitor(5, -1)"), Ok(Value::Int(-1)));
@@ -403,6 +404,10 @@ fn test_builtin_functions() {
     assert_eq!(eval("bitxor(6, 5)"), Ok(Value::Int(3)));
     assert_eq!(eval("bitnot(5)"), Ok(Value::Int(-6)));
     assert_eq!(eval("bitnot(-1)"), Ok(Value::Int(0)));
+    assert_eq!(eval("shl(5, 1)"), Ok(Value::Int(10)));
+    assert_eq!(eval("shl(-6, 5)"), Ok(Value::Int(-192)));
+    assert_eq!(eval("shr(5, 1)"), Ok(Value::Int(2)));
+    assert_eq!(eval("shr(-6, 5)"), Ok(Value::Int(-1)));
 }
 
 #[test]
@@ -582,6 +587,7 @@ fn test_shortcut_functions() {
         eval_number("abc"),
         Err(EvalexprError::VariableIdentifierNotFound("abc".to_owned()))
     );
+    assert_eq!(eval_number_with_context("3.5", &context), Ok(3.5));
     assert_eq!(eval_number_with_context("3", &context), Ok(3.0));
     assert_eq!(
         eval_number_with_context("true", &context),
@@ -593,6 +599,7 @@ fn test_shortcut_functions() {
         eval_number_with_context("abc", &context),
         Err(EvalexprError::VariableIdentifierNotFound("abc".to_owned()))
     );
+    assert_eq!(eval_number_with_context_mut("3.5", &mut context), Ok(3.5));
     assert_eq!(eval_number_with_context_mut("3", &mut context), Ok(3.0));
     assert_eq!(
         eval_number_with_context_mut("true", &mut context),
